# Generated by roxygen2: do not edit by hand

export(batch_svg_to_base64_chrome)
export(batch_svg_to_png)
export(batch_svg_to_png_chrome)
export(card_to_grob)
export(chrome_available)
export(compress_number)
export(create_badge)
export(create_badge_row)
export(create_bottom_logo_row)
export(create_logo_row)
export(ensure_chrome)
export(find_chrome_path)
export(font_available)
export(font_cache_dir)
export(get_font_css)
export(get_svg_path)
export(icon_building)
export(icon_construction)
export(icon_house)
export(icon_map_pin)
export(icon_money)
export(include_card)
export(include_card_png)
export(install_fonts)
export(is_light_color)
export(list_bundled_svgs)
export(list_fonts)
export(load_svg_for_embed)
export(register_cardargus_knitr)
export(register_font)
export(register_google_font)
export(save_card_for_knitr)
export(save_svg)
export(setup_fonts)
export(svg_card)
export(svg_to_formats)
export(svg_to_pdf)
export(svg_to_pdf_chrome)
export(svg_to_png)
export(svg_to_png_chrome)
export(svg_to_png_with_margin)
export(svgs_dir)
importFrom(cli,cli_abort)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_alert_warning)
importFrom(cli,cli_bullets)
importFrom(cli,cli_h1)
importFrom(cli,cli_h2)
importFrom(cli,cli_h3)
importFrom(cli,cli_progress_step)
importFrom(cli,cli_warn)
importFrom(grDevices,as.raster)
importFrom(grDevices,col2rgb)
importFrom(stats,setNames)
importFrom(utils,download.file)
importFrom(utils,unzip)
