% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chrome.R
\name{find_chrome_in_dir}
\alias{find_chrome_in_dir}
\title{Find Chrome executable in a directory}
\usage{
find_chrome_in_dir(dir)
}
\description{
Find Chrome executable in a directory
}
\keyword{internal}
