% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chrome.R
\name{chrome_cache_dir}
\alias{chrome_cache_dir}
\title{Get Chrome cache directory}
\usage{
chrome_cache_dir()
}
\description{
Get Chrome cache directory
}
\keyword{internal}
