% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chrome.R
\name{start_chrome_session}
\alias{start_chrome_session}
\title{Start a new Chrome session safely}
\usage{
start_chrome_session(old_session = NULL)
}
\arguments{
\item{old_session}{Previous session to close (can be NULL).}
}
\value{
New ChromoteSession object.
}
\description{
Creates a new ChromoteSession, optionally closing an existing one first.
Includes a small delay after closing to allow Chrome to clean up.
}
\keyword{internal}
