% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fonts.R
\name{setup_fonts}
\alias{setup_fonts}
\title{Setup showtext for cardargus}
\usage{
setup_fonts(fonts = c("Jost", "Montserrat"), auto = TRUE)
}
\arguments{
\item{fonts}{Character vector of Google Font names to register.}

\item{auto}{Enable showtext auto mode.}
}
\value{
Invisible NULL
}
\description{
Registers fonts (via sysfonts) and optionally enables showtext auto mode.
}
