% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chrome.R
\name{chrome_available}
\alias{chrome_available}
\title{Check if Chrome/Chromium is available for rendering}
\usage{
chrome_available(verbose = FALSE)
}
\arguments{
\item{verbose}{Print status messages (default FALSE).}
}
\value{
TRUE if Chrome is available, FALSE otherwise.
}
\description{
Checks whether the chromote package can find and use a Chrome or Chromium
installation for headless rendering.
}
\examples{
if (chrome_available()) {
   cat("Using Chrome")
} else {
   cat("Using Magick")
}

}
